@@ -7,6 +7,15 @@
 #
 #   The GNU General Public License, Version 3, June 2007
 #
+#
+# This file is part of App-SpreadRevolutionaryDate
+#
+# This software is Copyright (c) 2019-2024 by Gérald Sédrati.
+#
+# This is free software, licensed under:
+#
+#   The GNU General Public License, Version 3, June 2007
+#
 use 5.014;
 use utf8;
 package App::SpreadRevolutionaryDate::BlueskyLite;
@@ -64,9 +73,7 @@ sub new {
 sub create_post {
   my ($self, $text) = @_;
 
-  # parse text for URIs and mentions
   my $facets = $self->_generate_facets($text);
-  # build JSON and post to com.atproto.repo.createRecord endpoint
   my $json = encode_json({
     repo => $self->{did},
     collection => 'app.bsky.feed.post',
@@ -91,13 +98,16 @@ sub _generate_facets {
   my $pos = 0;
   foreach my $w (split /\s+/, $text) {
     my ($type, $attrib, $val);
-    $w =~ s/[\.,:;'"!\?]+$//;
+    $w =~ s/[.,:;'"!\?()]+$//;
+    $w =~ s/^[.,:;'"!\?()]+//g;
     if ($w =~ /^https?\:\/\//) {
       $type = 'app.bsky.richtext.facet#link';
       $attrib = 'uri';
       $val = $w;
 
-      $pos = index($text, $w, $pos) + 1;
+      use bytes;
+      $pos = index($text, $w, $pos);
+      no bytes;
       my $end = $pos + length($w);
       push @$output, {
         features => [{
@@ -135,7 +145,7 @@ App::SpreadRevolutionaryDate::BlueskyLite - .
 
 =head1 VERSION
 
-version 0.34
+version 0.35
 
 =head1 Methods
 
